@@ -52,7 +52,7 @@ ChalRespPage::ChalRespPage(QWidget *parent) :
     connectHelpButtons();
 
     //Connect other signals and slots
-    connect(YubiKeyFinder::getInstance(), SIGNAL(keyFound(bool, bool*)),
+    connect(YubiKeyFinder::getInstance(), SIGNAL(keyFound(bool, bool*, int)),
             this, SLOT(keyFound(bool, bool*)));
 
     connect(ui->quickResetBtn, SIGNAL(clicked()),
