@@ -55,7 +55,7 @@ OtpPage::OtpPage(QWidget *parent) :
     connectHelpButtons();
 
     //Connect other signals and slots
-    connect(YubiKeyFinder::getInstance(), SIGNAL(keyFound(bool, bool*)),
+    connect(YubiKeyFinder::getInstance(), SIGNAL(keyFound(bool, bool*, int)),
             this, SLOT(keyFound(bool, bool*)));
 
     connect(ui->quickWriteConfigBtn, SIGNAL(clicked()),
@@ -436,7 +436,7 @@ void OtpPage::quickConfigWritten(bool written, __attribute__((unused)) const QSt
 void OtpPage::uploadQuickConfig() {
     m_tempFile.setFileTemplate(QDir::tempPath() + "/ykpers.XXXXXX.html");
     m_tempFile.open();
-    m_tempFile.write(m_uploadUrl.toAscii(), m_uploadUrl.length());
+    m_tempFile.write(m_uploadUrl.toLatin1(), m_uploadUrl.length());
     m_tempFile.close();
     qDebug() << "temporary file for upload is: " << m_tempFile.fileName();
     QDesktopServices::openUrl(QUrl::fromLocalFile(m_tempFile.fileName()));
